==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/WaitProcess.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub WaitProcess::BEGIN{package WaitProcess;no warnings;require POSIX;do{
"\x50\x4f\x53\x49\x58"->import ("\x3a\x73\x69\x67\x6e\x61\x6c\x5f\x68",
"\x3a\x65\x72\x72\x6e\x6f\x5f\x68",
"\x3a\x73\x79\x73\x5f\x77\x61\x69\x74\x5f\x68")};}sub WaitProcess::BEGIN{package
 WaitProcess;no warnings;require Exception::Internal;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
import};}package WaitProcess;no warnings;(our $errorNoProcessToWait=(-
(0x1bc5+ 2550-0x25ba)));(our $statusRunning=(0x067b+ 227-0x075e));(our 
$statusExited=(0x04e1+ 6468-0x1e24));(our $statusStopped=(0x0bb9+ 6542-0x2545));
(our $statusDied=(0x141a+ 3347-0x212a));my ($__resultStatus);my ($__resultPid);my (
$__parameterPid);my ($__parameterOptions);(my $__returnedStatus=
$errorNoProcessToWait);sub waitProcess{($__parameterPid=shift (@_));(
$__parameterOptions=shift (@_));my ($waitpidOption);(my $timeOut=
(0x0d8d+ 1147-0x1208));if (($__parameterOptions gt (0x185d+ 3526-0x2623))){(
$waitpidOption=$NXBits::WAIT_UNTRACED);($timeOut=$__parameterOptions);
Logger::debug (((((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27\x20\x75\x73\x69\x6e\x67\x20").$timeOut).
"\x73\x20\x61\x73\x20\x74\x69\x6d\x65\x6f\x75\x74"));}else{($waitpidOption=
$NXBits::WAIT_NOHANG);Logger::debug (((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27"));}(my $timedOut=(0x0357+ 7158-0x1f4c));eval{(
$__resultPid=(0x0641+  79-0x0690));if (($timeOut==(0x14db+ 2110-0x1d19))){(
$__resultPid=Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption));if (
($__resultPid>(0x0d96+ 3553-0x1b77))){($__resultStatus=
Common::NXProcess::getExitValue ($__resultPid));}}else{($__resultPid=
Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption,$timeOut));if ((
$__resultPid eq (0x1d6c+ 577-0x1fad))){($timedOut=(0x016c+ 7605-0x1f20));}else{(
$__resultStatus=Common::NXProcess::getExitValue ($__parameterPid));($timedOut=
(0x1662+ 1022-0x1a60));}}};if ($timedOut){Logger::debug (((
"\x72\x65\x61\x63\x68\x65\x64\x20\x74\x69\x6d\x65\x6f\x75\x74\x20\x6f\x66\x20".
$timeOut).((
"\x73\x20\x77\x68\x69\x6c\x65\x20\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
.$__parameterPid)."\x27")));($__returnedStatus=$statusRunning);return (
$__returnedStatus);}elsif ($@){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((
"\x55\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x20\x65\x72\x72\x6f\x72\x3a\x20\x27".
$@)."\x27"));}if (($__resultPid==(-(0x004f+ 8717-0x225b)))){Logger::debug (((
"\x6e\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x3a\x20\x27"
.$__parameterPid)."\x27\x20\x74\x6f\x20\x77\x61\x69\x74"));($__returnedStatus=
$errorNoProcessToWait);return ($__returnedStatus);}if (WIFEXITED (
$__resultStatus)){Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x65\x78\x69\x74\x65\x64"));(
$__returnedStatus=$statusExited);return ($__returnedStatus);}if (WIFSIGNALED (
$__resultStatus)){Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x64\x69\x65\x64"));($__returnedStatus
=$statusDied);return ($__returnedStatus);}if (WIFSTOPPED ($__resultStatus)){
Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x77\x61\x73\x20\x73\x74\x6f\x70\x70\x65\x64"));(
$__returnedStatus=$statusStopped);return ($__returnedStatus);}($__returnedStatus
=$errorNoProcessToWait);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((((
"\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x27"
.$__resultStatus)."\x27\x20\x66\x6f\x72\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
).$__parameterPid)."\x27"));}sub getPid{if (($__returnedStatus==
$errorNoProcessToWait)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x20\x77\x68\x65\x6e\x20\x6c\x61\x73\x74\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x65\x72\x72\x6f\x72\x4e\x6f\x50\x72\x6f\x63\x65\x73\x73\x54\x6f\x57\x61\x69\x74\x27"
);}Logger::debug ((("\x70\x69\x64\x20\x69\x73\x20\x27".$__resultPid)."\x27"));
return ($__resultPid);}sub getSig{if (($__returnedStatus==$statusDied)){(my $sig
=WTERMSIG ($__resultStatus));Logger::debug (((
"\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"));return ($sig);
}if (($__returnedStatus==$statusStopped)){(my $sig=WSTOPSIG ($__resultStatus));
Logger::debug ((("\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"
));return ($sig);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x53\x74\x6f\x70\x70\x65\x64\x27\x20\x6f\x72\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x44\x69\x65\x64\x27"
);}sub getExitStatus{if (($__returnedStatus==$statusExited)){(my $exitStatus=
WEXITSTATUS ($__resultStatus));Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x65\x78\x69\x74\x20\x73\x74\x61\x74\x75\x73\x20\x69\x73\x20\x27"
.$exitStatus)."\x27"));return ($exitStatus);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x45\x78\x69\x74\x65\x64\x27"
);}return ((0x0254+ 8083-0x21e6));

==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/WaitProcess.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub WaitProcess::BEGIN{package WaitProcess;no warnings;require POSIX;do{
"\x50\x4f\x53\x49\x58"->import ("\x3a\x73\x69\x67\x6e\x61\x6c\x5f\x68",
"\x3a\x65\x72\x72\x6e\x6f\x5f\x68",
"\x3a\x73\x79\x73\x5f\x77\x61\x69\x74\x5f\x68")};}sub WaitProcess::BEGIN{package
 WaitProcess;no warnings;require Exception::Internal;do{
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
import};}package WaitProcess;no warnings;(our $errorNoProcessToWait=(-
(0x1a8a+ 348-0x1be5)));(our $statusRunning=(0x20b2+ 203-0x217d));(our 
$statusExited=(0x01f1+ 6697-0x1c19));(our $statusStopped=(0x005a+ 9161-0x2421));
(our $statusDied=(0x0742+ 6537-0x20c8));my ($__resultStatus);my ($__resultPid);my (
$__parameterPid);my ($__parameterOptions);(my $__returnedStatus=
$errorNoProcessToWait);sub waitProcess{($__parameterPid=shift (@_));(
$__parameterOptions=shift (@_));my ($waitpidOption);(my $timeOut=
(0x0381+ 2974-0x0f1f));if (($__parameterOptions gt (0x090f+ 4590-0x1afd))){(
$waitpidOption=$NXBits::WAIT_UNTRACED);($timeOut=$__parameterOptions);
Logger::debug (((((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27\x20\x75\x73\x69\x6e\x67\x20").$timeOut).
"\x73\x20\x61\x73\x20\x74\x69\x6d\x65\x6f\x75\x74"));}else{($waitpidOption=
$NXBits::WAIT_NOHANG);Logger::debug (((
"\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x3a\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27"
.$__parameterPid)."\x27"));}(my $timedOut=(0x22d5+ 920-0x266c));eval{(
$__resultPid=(0x1d2b+ 658-0x1fbd));if (($timeOut==(0x0452+ 5080-0x182a))){(
$__resultPid=Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption));if (
($__resultPid>(0x03c1+ 3232-0x1061))){($__resultStatus=
Common::NXProcess::getExitValue ($__resultPid));}}else{($__resultPid=
Common::NXProcess::nxwaitpid ($__parameterPid,$waitpidOption,$timeOut));if ((
$__resultPid eq (0x0bd3+ 1938-0x1365))){($timedOut=(0x1901+ 448-0x1ac0));}else{(
$__resultStatus=Common::NXProcess::getExitValue ($__parameterPid));($timedOut=
(0x077f+ 3045-0x1364));}}};if ($timedOut){Logger::debug (((
"\x72\x65\x61\x63\x68\x65\x64\x20\x74\x69\x6d\x65\x6f\x75\x74\x20\x6f\x66\x20".
$timeOut).((
"\x73\x20\x77\x68\x69\x6c\x65\x20\x77\x61\x69\x74\x69\x6e\x67\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
.$__parameterPid)."\x27")));($__returnedStatus=$statusRunning);return (
$__returnedStatus);}elsif ($@){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((
"\x55\x6e\x65\x78\x70\x65\x63\x74\x65\x64\x20\x65\x72\x72\x6f\x72\x3a\x20\x27".
$@)."\x27"));}if (($__resultPid==(-(0x0cb3+ 875-0x101d)))){Logger::debug (((
"\x6e\x6f\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x3a\x20\x27"
.$__parameterPid)."\x27\x20\x74\x6f\x20\x77\x61\x69\x74"));($__returnedStatus=
$errorNoProcessToWait);return ($__returnedStatus);}if (WIFEXITED (
$__resultStatus)){Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x65\x78\x69\x74\x65\x64"));(
$__returnedStatus=$statusExited);return ($__returnedStatus);}if (WIFSIGNALED (
$__resultStatus)){Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x68\x61\x73\x20\x64\x69\x65\x64"));($__returnedStatus
=$statusDied);return ($__returnedStatus);}if (WIFSTOPPED ($__resultStatus)){
Logger::error (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x77\x69\x74\x68\x20\x70\x69\x64\x20\x27".
$__parameterPid)."\x27\x20\x77\x61\x73\x20\x73\x74\x6f\x70\x70\x65\x64"));(
$__returnedStatus=$statusStopped);return ($__returnedStatus);}($__returnedStatus
=$errorNoProcessToWait);
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (((((
"\x55\x6e\x6b\x6e\x6f\x77\x6e\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x27"
.$__resultStatus)."\x27\x20\x66\x6f\x72\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x27"
).$__parameterPid)."\x27"));}sub getPid{if (($__returnedStatus==
$errorNoProcessToWait)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x20\x77\x68\x65\x6e\x20\x6c\x61\x73\x74\x20\x72\x65\x73\x75\x6c\x74\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x65\x72\x72\x6f\x72\x4e\x6f\x50\x72\x6f\x63\x65\x73\x73\x54\x6f\x57\x61\x69\x74\x27"
);}Logger::debug ((("\x70\x69\x64\x20\x69\x73\x20\x27".$__resultPid)."\x27"));
return ($__resultPid);}sub getSig{if (($__returnedStatus==$statusDied)){(my $sig
=WTERMSIG ($__resultStatus));Logger::debug (((
"\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"));return ($sig);
}if (($__returnedStatus==$statusStopped)){(my $sig=WSTOPSIG ($__resultStatus));
Logger::debug ((("\x73\x69\x67\x6e\x61\x6c\x20\x77\x61\x73\x20\x27".$sig)."\x27"
));return ($sig);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x53\x74\x6f\x70\x70\x65\x64\x27\x20\x6f\x72\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x44\x69\x65\x64\x27"
);}sub getExitStatus{if (($__returnedStatus==$statusExited)){(my $exitStatus=
WEXITSTATUS ($__resultStatus));Logger::debug (((
"\x70\x72\x6f\x63\x65\x73\x73\x20\x65\x78\x69\x74\x20\x73\x74\x61\x74\x75\x73\x20\x69\x73\x20\x27"
.$exitStatus)."\x27"));return ($exitStatus);}
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x61\x6c\x6c\x20\x74\x68\x69\x73\x20\x6d\x65\x74\x68\x6f\x64\x2c\x20\x70\x72\x65\x76\x69\x6f\x75\x73\x20\x70\x72\x6f\x63\x65\x73\x73\x20\x73\x74\x61\x74\x75\x73\x20\x77\x61\x73\x20\x6e\x6f\x74\x20\x27\x57\x61\x69\x74\x50\x72\x6f\x63\x65\x73\x73\x3a\x3a\x73\x74\x61\x74\x75\x73\x45\x78\x69\x74\x65\x64\x27"
);}return ((0x0a02+  90-0x0a5b));
